/*
 * Copyright (C) 2008 Nikolas Zimmermann <zimmermann@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef SVGFontData_h
#define SVGFontData_h

#if ENABLE(SVG_FONTS)
// FIXME khtml #include "SVGFontFaceElement.h"

namespace WebCore
{

class SVGFontData
{
public:
    SVGFontData(/*FIXME khtml SVGFontFaceElement**/);
    virtual ~SVGFontData();

    // FIXME khtml SVGFontFaceElement* svgFontFaceElement() const { return m_svgFontFaceElement.get(); }

    float horizontalOriginX() const
    {
        return m_horizontalOriginX;
    }
    float horizontalOriginY() const
    {
        return m_horizontalOriginY;
    }
    float horizontalAdvanceX() const
    {
        return m_horizontalAdvanceX;
    }

    float verticalOriginX() const
    {
        return m_verticalOriginX;
    }
    float verticalOriginY() const
    {
        return m_verticalOriginY;
    }
    float verticalAdvanceY() const
    {
        return m_verticalAdvanceY;
    }

private:
    //FIXME khtml RefPtr<SVGFontFaceElement> m_svgFontFaceElement;

    float m_horizontalOriginX;
    float m_horizontalOriginY;
    float m_horizontalAdvanceX;

    float m_verticalOriginX;
    float m_verticalOriginY;
    float m_verticalAdvanceY;
};

} // namespace WebCore

#endif
#endif // SVGFontData_h
